## wiki-con - A console app that displays random facts using the Wikipedia API

[![Tests](https://github.com/kevinbowen777/wiki-con/workflows/Tests/badge.svg)](https://github.com/kevinbowen777/wiki-con/actions?workflow=Tests)

### Installation
 - `git clone https://github.com/kevinbowen777/wiki-con.git`
 - `cd wiki-con`
 - `poetry run wiki_con`

---
## Features
 - TBD

---
[![License](https://img.shields.io/badge/license-MIT-green)](https://github.com/kevinbowen777/wiki-con/blob/master/LICENSE)
---
### Reporting Bugs

   Visit the [Issues page](https://github.com/kevinbowen777/wiki-con/issues) to view currently open bug reports or open a new issue.
